@@ -218,9 +218,9 @@
     ((membership :status 'leave))
     (low-priority)
     (unread)
+    people
     ((latest :name "Last 24h" :newer-than 86400))
-    (latest :name "Old" :older-than (* 86400 90))
-    (people)
+    (latest :name "Older than 90d" :older-than (* 86400 90))
     freshness
     (space))
   "Default keys."
@@ -350,6 +350,15 @@
         (number-to-string member-count)
       "")))
 
+(ement-taxy-define-column #("Notifications" 0 5 (help-echo "Notification state")) ()
+  (pcase-let* ((`[,room ,session] item))
+    (pcase (ement-room-notification-state room session)
+      ('nil "default")
+      ('all-loud "all (loud)")
+      ('all "all")
+      ('mentions-and-keywords "mentions")
+      ('none "none"))))
+
 (ement-taxy-define-column #("B" 0 1 (help-echo "Buffer exists for room")) ()
   (pcase-let ((`[,(cl-struct ement-room (local (map buffer))) ,_session] item))
     (if buffer
@@ -436,6 +445,15 @@ DISPLAY-BUFFER-ACTION."
                 (item-invited-p
                  (item) (pcase-let ((`[,(cl-struct ement-room status) ,_session] item))
                           (equal 'invite status)))
+                (taxy-latest-ts
+                 (taxy) (apply #'max most-negative-fixnum
+                               (delq nil
+                                     (list
+                                      (when (taxy-items taxy)
+                                        (item-latest-ts (car (taxy-items taxy))))
+                                      (when (taxy-taxys taxy)
+                                        (cl-loop for sub-taxy in (taxy-taxys taxy)
+                                                 maximizing (taxy-latest-ts sub-taxy)))))))
                 (t<nil (a b) (and a (not b)))
                 (t>nil (a b) (and (not a) b))
                 (make-fn (&rest args)
@@ -479,13 +497,11 @@ DISPLAY-BUFFER-ACTION."
                          ;; sorted last.
                          (taxy-sort #'t>nil #'item-left-p)
                          (taxy-sort* #'string< #'taxy-name)
-                         (taxy-sort* #'> (lambda (taxy)
-                                           (if (taxy-items taxy)
-                                               (item-latest-ts (car (taxy-items taxy)))
-                                             most-negative-fixnum)))
+                         (taxy-sort* #'> #'taxy-latest-ts)
                          (taxy-sort* #'t<nil (first-item item-unread-p))
                          (taxy-sort* #'t<nil (first-item item-favourite-p))
                          (taxy-sort* #'t<nil (first-item item-invited-p))
+                         (taxy-sort* #'t>nil (first-item item-space-p))
                          (taxy-sort* #'t>nil (first-item item-low-priority-p))
                          (taxy-sort* #'t>nil (first-item item-left-p)))))
                (taxy-magit-section-insert-indent-items nil)
